@@ -880,7 +880,7 @@ public:
     QHash<QString, KAboutData *> m_pluginData;
 };
 
-Q_GLOBAL_STATIC(KAboutDataRegistry, s_registry);
+Q_GLOBAL_STATIC(KAboutDataRegistry, s_registry)
 
 KAboutData KAboutData::applicationData()
 {
@@ -910,7 +910,6 @@ void KAboutData::setApplicationData(const KAboutData &aboutData)
         app->setApplicationName(aboutData.componentName());
         app->setOrganizationDomain(aboutData.organizationDomain());
         app->setProperty("applicationDisplayName", aboutData.displayName());
-        app->setProperty("applicationIconName", s_registry->m_appData->programIconName());
     }
 }
 
@@ -940,6 +939,13 @@ bool KAboutData::setupCommandLine(QCommandLineParser *parser)
         parser->setApplicationDescription(d->_shortDescription);
     }
 
+    parser->addHelpOption();
+
+    QCoreApplication *app = QCoreApplication::instance();
+    if (app && !app->applicationVersion().isEmpty()) {
+        parser->addVersionOption();
+    }
+
     return parser->addOption(QCommandLineOption(QStringLiteral("author"), QCoreApplication::translate("KAboutData CLI", "Show author information.")))
            && parser->addOption(QCommandLineOption(QStringLiteral("license"), QCoreApplication::translate("KAboutData CLI", "Show license information.")));
 }
@@ -961,6 +967,15 @@ void KAboutData::processCommandLine(QCommandLineParser *parser)
                 printf("%s\n", qPrintable(authorData));;
             }
         }
+        if (!customAuthorTextEnabled()) {
+            if (bugAddress() == QLatin1String("submit@bugs.kde.org") ) {
+                printf("%s\n", qPrintable(QCoreApplication::translate("KAboutData CLI", "Please use http://bugs.kde.org to report bugs.")));
+            } else if (!bugAddress().isEmpty()) {
+                printf(qPrintable(QCoreApplication::translate("KAboutData CLI", "Please report bugs to %s.\n")), qPrintable(bugAddress()));
+            }
+        } else {
+            printf("%s\n", qPrintable(customAuthorPlainText()));
+        }
     } else if (parser->isSet(QStringLiteral("license"))) {
         foundArgument = true;
         Q_FOREACH (const KAboutLicense &license, d->_licenseList) {
